parse_collect_event_hypersync

Function parse_collect_event_hypersync 

pub fn parse_collect_event_hypersync(
    dex: SharedDex,
    log: &HypersyncLog,
) -> Result<CollectEvent>
Parses a collect event from a Uniswap V3 log.

Errors

Returns an error if the log parsing fails or if the event data is invalid.

Panics

Panics if the contract address is not set in the log.